<?PHP
/**
* News Module
*
* This module will get all the news pages
*
* @copyright CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author Astalavista Development Team <thun@astalvista.ch>
* @module      news
* @modulegroup modules
* @access public
* @version 1.0.0   
*/

require_once ASCMS_CORE_MODULE_PATH . '/news/newsLib.class.php';

class news extends newsLibrary
{  
    var $newsTitle;
    var $langId;
    var $arrSettings = array(); 
    var $_objTpl;
    var $_submitMessage;
    
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */   
    function news($pageContent)
    { 
    	$this->__construct($pageContent); 
    }    
	
    /**
     * PHP5 constructor
     * @param  string  $pageContent
     * @global string  $_LANGID      
     * @access public     
     */
    function __construct($pageContent)
    {  
	    global $_LANGID;
	    $this->getSettings();
	    $this->pageContent = $pageContent;
	    $this->langId = $_LANGID;
	    
	    $this->_objTpl = &new HTML_Template_Sigma();
	    $this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);
	}	
	
	/**
	* Get page
	*
	* @access public
	* @return string content
	*/
    function getNewsPage()
    {
    	if (!isset($_REQUEST['cmd'])) {
    		$_REQUEST['cmd'] = '';
    	}
    	
    	switch($_REQUEST['cmd']) {
    	case 'details':
		   	return $this->getDetails();
		   	break;
		    	
		case 'submit':
			return $this->_submit();
		    break;
		case 'feed':
			return $this->_showFeed();
			break;
		
	    default:
			return $this->getHeadlines();
		    break;
    	}
    }
	
	/**
	* Gets the news details
	*
	* @global	 array     $_CONFIG 
	* @global	 array     $_ARRAYLANG
	* @global	 object    $objDatabase    
	* @return    string    parsed content                                                                               
	*/
	function getDetails()
	{
		global $_CONFIG, $objDatabase, $_ARRAYLANG;	
		
	    $this->_objTpl->setTemplate($this->pageContent);
	    $newsid = intval($_GET['newsid']);
	    
		if ($newsid!=0) {
			$objResult = $objDatabase->SelectLimit("SELECT id,source,changelog,url1,url2,text,date,changelog,title 
			              FROM ".DBPREFIX."module_news 
			             WHERE status = 1
			               AND id = $newsid 
			               AND lang=".$this->langId." 
			               AND (startdate<=CURDATE() OR startdate='0000-00-00')
			               AND (enddate>=CURDATE() OR enddate='0000-00-00')", 1);
			
			if ($objResult !== false) {
				while (!$objResult->EOF) {
					$lastUpdate	= $objResult->fields['changelog'];
					$source	    = htmlspecialchars($objResult->fields['source']);
					$url1 	    = htmlspecialchars($objResult->fields['url1']);
					$url2 	    = htmlspecialchars($objResult->fields['url2']);
					$newsUrl    = "";
					$newsSource = "";
					$newsLastUpdate = "";
				
					if (!empty($url1)) {
						 $newsUrl = $_ARRAYLANG['TXT_IMPORTANT_HYPERLINKS']."<br /><a target='new' href='$url1'>$url1</a><br />";
					}
					if (!empty($url2)) {
						 $newsUrl .= "<a target='new' href='$url2'>$url2</a><br />";
					}
					if (!empty($source)) {
						 $newsSource = $_ARRAYLANG['TXT_NEWS_SOURCE']."<br /><a target='new' href='$source'>$source</a><br />";
					}
					if (!empty($lastUpdate)) {
						 $newsLastUpdate = $_ARRAYLANG['TXT_LAST_UPDATE']."<br />".date(ASCMS_DATE_FORMAT,$objResult->fields['changelog']);
					}				
					
					$newstitle = stripslashes($objResult->fields['title']);
					$this->_objTpl->setVariable(array(							   
					   'NEWS_DATE'   	 => date(ASCMS_DATE_FORMAT,$objResult->fields['date']),
					   'NEWS_TITLE'		 => $newstitle,
					   'NEWS_TEXT'		 => stripslashes($objResult->fields['text']),
					   'NEWS_LASTUPDATE' => $newsLastUpdate,
					   'NEWS_SOURCE' 	 => $newsSource,
					   'NEWS_URL'		 => $newsUrl
					));
					
					$objResult->MoveNext();
				}
			}
		} else {
			header("Location: ?section=news");
			exit;
		}
		
		$this->newsTitle = strip_tags($newstitle);
		return $this->_objTpl->get();
	}
	
	/**
	* Gets the list with the headlines
	*
	* @global	 object    $objDatabase   
	* @param     integer   $pos
	* @param     string	   $page_content
	* @return    string    parsed content                                                                              
	*/
	function getHeadlines()
	{
		global $_CONFIG, $objDatabase, $_ARRAYLANG;	
	   
		$selected = "";
		$newsfilter = "";
		$paging = "";
		$pos = 0;
		$i="";
		
		if (isset($_GET['pos'])) {
			$pos = intval($_GET['pos']);
		}
		
		$this->_objTpl->setTemplate($this->pageContent);
		
		if (!empty($_REQUEST['category'])) {
			$selected= intval($_REQUEST['category']);
			$newsfilter=" n.catid='$selected' AND ";
		}
		
		$this->_objTpl->setVariable(array(
			"NEWS_NO_CATEGORY"		=> $_ARRAYLANG['TXT_CATEGORY'],
			"NEWS_CAT_DROPDOWNMENU"	=> $this->getCategoryMenu($this->langId, $selected),
			"TXT_PERFORM"			=> $_ARRAYLANG['TXT_PERFORM'],
			"TXT_CATEGORY"			=> $_ARRAYLANG['TXT_CATEGORY'],
			"TXT_DATE"				=> $_ARRAYLANG['TXT_DATE'],
			"TXT_TITLE"				=> $_ARRAYLANG['TXT_TITLE']
		));
	    
	    
		$query = "SELECT n.date AS newsdate,
		                 n.id AS newsid,
		                 n.title AS newstitle,
		                 nc.name AS name 
		            FROM ".DBPREFIX."module_news AS n,
		                 ".DBPREFIX."module_news_categories AS nc  
		           WHERE status = 1
		             AND n.lang=".$this->langId." 
		             AND $newsfilter n.catid=nc.catid
	                 AND (startdate<=CURDATE() OR startdate='0000-00-00')
	                 AND (enddate>=CURDATE() OR enddate='0000-00-00') 	
		        ORDER BY newsdate DESC";
		
		/***start paging ****/
		
		$objResult = $objDatabase->Execute($query);		
		$count = $objResult->RecordCount();
		if ($count>intval($_CONFIG['corePagingLimit'])) {
		    $paging = getPaging($count, $pos, "&section=news", $_ARRAYLANG['TXT_NEWS_MESSAGES'], true);
		}
		$this->_objTpl->setVariable("NEWS_PAGING", $paging);
		$objResult = $objDatabase->SelectLimit($query, $_CONFIG['corePagingLimit'], $pos);
		
		/*** end paging ***/
		
		if ($count>=1) {
			while (!$objResult->EOF) {
				($i % 2) ? $class  = 'row1' : $class  = 'row2';
				$this->_objTpl->setVariable(array(
						   'NEWS_CSS'      => $class,							   
						   'NEWS_LONG_DATE'  => date(ASCMS_DATE_FORMAT,$objResult->fields['newsdate']),
						   'NEWS_DATE'       => date(ASCMS_DATE_SHORT_FORMAT, $objResult->fields['newsdate']),
						   'NEWS_LINK'	   => "<a href=\"?section=news&amp;cmd=details&amp;newsid=".$objResult->fields['newsid']."\">".stripslashes($objResult->fields['newstitle'])."</a>",
						   'NEWS_CATEGORY' => stripslashes($objResult->fields['name']),
				        ));
				        
				$this->_objTpl->parse("newsrow");
				$i++;
				$objResult->MoveNext();
			}	
		} else {
			$this->_objTpl->setVariable(array(
				'NEWS_DATE'		=> '',
				'NEWS_LINK'		=> '',
				'NEWS_CATEGORY'	=> $_ARRAYLANG['TXT_NO_NEWS_FOUND']
			));
			$this->_objTpl->parse("newsrow");
		}			
	    return $this->_objTpl->get();
	}
	
	/**
	* Gets the global page title
	*
	* @param     string	   (optional)$pageTitle                                                                             
	*/	
	function getPageTitle($pageTitle="")
	{
	    if (empty($this->newsTitle)) {
	        $this->newsTitle = strip_tags(stripslashes($pageTitle));
	    }		
	}
	
	/**
	* Get the submit page
	*
	* Get the submit, login or the noaccess page depending on the configuration
	*
	* @access private
	* @global array $_ARRAYLANG
	* @global object $objAuth
	* @global object $objPerm
	* @see HTML_Template_Sigma::setTemplate(), modulemanager::getModules(), Permission::checkAccess(), Auth::checkAuth()
	* @return string content
	*/
	function _submit()
	{
		global $_ARRAYLANG, $objAuth, $objPerm;
		
		$this->_objTpl->setTemplate($this->pageContent);
		
		require_once ASCMS_CORE_PATH.'/modulemanager.class.php';
		$objModulManager = &new modulemanager();
		$arrInstalledModules = $objModulManager->getModules();
		if (in_array(23, $arrInstalledModules)) {
			$communityModul = true;
		} else {
			$communityModul = false;
		}
		
		if (!$this->arrSettings['news_submit_news'] == '1' || (!$communityModul && $this->arrSettings['news_submit_only_community'] == '1')) {
			header('Location: index.php?section=news');
			exit;
		} elseif ($this->arrSettings['news_submit_only_community'] == '1') {
			if ($objAuth->checkAuth()) {
				if (!$objPerm->checkAccess(61, 'static')) {
					header("Location: ?section=login&cmd=noaccess");
					exit;
				}
			} else {
				$link = base64_encode($_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING']);
				header("Location: ?section=login&redirect=".$link);
				exit;
			}
		}
		
		$newsCat = "";
		$newsText = "";
		$newsTitle = "";
		$newsSource = "http://";
		$newsUrl1 = "http://";
		$newsUrl2 = "http://";
		
		if (isset($_POST['submitNews'])) {
			$objValidator = &new FWValidator();
			
			$_POST['newsTitle'] = contrexx_strip_tags(html_entity_decode($_POST['newsTitle']));
		    $_POST['newsText'] = get_magic_quotes_gpc() ? stripslashes($_POST['newsText']) : $_POST['newsText'];
		    $_POST['newsText'] = $this->filterBodyTag($_POST['newsText']);
		    $_POST['newsSource'] = $objValidator->getUrl(contrexx_strip_tags(html_entity_decode($_POST['newsSource'])));
		    $_POST['newsUrl1'] = $objValidator->getUrl(contrexx_strip_tags(html_entity_decode($_POST['newsUrl1'])));
		    $_POST['newsUrl2'] = $objValidator->getUrl(contrexx_strip_tags(html_entity_decode($_POST['newsUrl2'])));
		    $_POST['newsCat'] = intval($_POST['newsCat']);
			
			if (!empty($_POST['newsTitle']) && !empty($_POST['newsText'])) {
				if (!$this->_insert()) {
					$newsTitle = $_POST['newsTitle'];
					$newsSource = $_POST['newsSource'];
					$newsUrl1 = $_POST['newsUrl1'];
					$newsUrl2 = $_POST['newsUrl2'];
					$newsCat = $_POST['newsCat'];
					$newsText = $_POST['newsText'];
				}
			} else {
				$newsTitle = $_POST['newsTitle'];
				$newsSource = $_POST['newsSource'];
				$newsUrl1 = $_POST['newsUrl1'];
				$newsUrl2 = $_POST['newsUrl2'];
				$newsCat = $_POST['newsCat'];
				$newsText = $_POST['newsText'];
				
				$this->_submitMessage = $_ARRAYLANG['TXT_SET_NEWS_TITLE_AND_TEXT']."<br /><br />";
			}
		}
		
		$this->_objTpl->setVariable(array(
			'TXT_NEWS_MESSAGE'		=> $_ARRAYLANG['TXT_NEWS_MESSAGE'],
			'TXT_TITLE'				=> $_ARRAYLANG['TXT_TITLE'],
			'TXT_CATEGORY'			=> $_ARRAYLANG['TXT_CATEGORY'],
			'TXT_HYPERLINKS'		=> $_ARRAYLANG['TXT_HYPERLINKS'],
			'TXT_EXTERNAL_SOURCE'	=> $_ARRAYLANG['TXT_EXTERNAL_SOURCE'],
			'TXT_LINK'				=> $_ARRAYLANG['TXT_LINK'],
			'TXT_NEWS_CONTENT'		=> $_ARRAYLANG['TXT_NEWS_CONTENT'],
			'TXT_SUBMIT_NEWS'		=> $_ARRAYLANG['TXT_SUBMIT_NEWS'],
			'NEWS_TEXT'				=> get_wysiwyg_editor('newsText', $newsText, 'news'),
			'NEWS_CAT_MENU'         => $this->getCategoryMenu($this->langId, $newsCat),
			'NEWS_TITLE'			=> $newsTitle,
			'NEWS_SOURCE'			=> $newsSource,
			'NEWS_URL1'				=> $newsUrl1,
			'NEWS_URL2'				=> $newsUrl2,
			'NEWS_STATUS_MESSAGE'	=> $this->_submitMessage
		));
		
		return $this->_objTpl->get();
	}

	
	
	/**
	* Insert a new news message
	*
	* @access private
	* @global object $objDatabase
	* @global array $_ARRAYLANG
	* @return boolean true on success - false on failure
	*/
	function _insert()
	{
		global $objDatabase, $_ARRAYLANG;
		
	    $date = time();
	    $newstitle = $_POST['newsTitle'];
	    $newstext = addslashes($_POST['newsText']);
	    $newssource	= $_POST['newsSource'];
	    $newsurl1 = $_POST['newsUrl1'];
	    $newsurl2 = $_POST['newsUrl2'];
	    $newscat = $_POST['newsCat'];
	    $userid = intval($_SESSION['auth']['userid']);
		
	    $objResult = $objDatabase->Execute("INSERT INTO ".DBPREFIX."module_news (
	    	id,
			date,
			title,
			text,
			source,
			url1,
			url2,
			catid,
			lang, 
			startdate,
			enddate,
			status,
			validated,
			userid, 
			changelog
			) VALUES (
			'',
			'$date', 
			'$newstitle', 
			'$newstext', 
			'$newssource', 
			'$newsurl1', 
			'$newsurl2', 
			'$newscat',
			'$this->langId',
			'',
			'',
			'".($this->arrSettings['news_activate_submitted_news'] == '1' ? "1" : "0")."',
			'".($this->arrSettings['news_activate_submitted_news'] == '1' ? "1" : "0")."',
			'$userid',
			'$date')"
	    );
	    
        if ($objResult !== false){
    	    $this->_submitMessage = $_ARRAYLANG['TXT_NEWS_SUCCESSFULLY_SUBMITED']."<br /><br />";
    	    return true;
        } else{
        	$this->_submitMessage = $_ARRAYLANG['TXT_NEWS_SUBMIT_ERROR']."<br /><br />";
        	return false;
        }
	}
	
	/**
	* Show feed page
	*
	* @access private
	* @global array $_ARRAYLANG
	* @return string Template output
	*/
	function _showFeed()
	{
		global $_ARRAYLANG, $objInit, $objDatabase;
		
		$this->_objTpl->setTemplate($this->pageContent);
		
		$objResult = $objDatabase->Execute("SELECT lang FROM ".DBPREFIX."languages WHERE id=".$objInit->userFrontendLangId);
		$serverPort = $_SERVER['SERVER_PORT'] == 80 ? "" : ":".intval($_SERVER['SERVER_PORT']);
		$rssFeedUrl = "http://".$_SERVER['SERVER_NAME'].$serverPort.ASCMS_PATH_OFFSET."/feed/news_headlines_".$objResult->fields['lang'].".xml";
		$jsFeedUrl = "http://".$_SERVER['SERVER_NAME'].$serverPort.ASCMS_PATH_OFFSET."/feed/news_".$objResult->fields['lang'].".js";
		$hostname = addslashes(htmlspecialchars($_SERVER['SERVER_NAME']));
		
		$rss2jsCode = <<<RSS2JSCODE
&lt;script language="JavaScript" type="text/javascript"&gt;
&lt;!--
// {$_ARRAYLANG['TXT_NEWS_OPTIONAL_VARS']}
var rssFeedFontColor = "#000000"; // {$_ARRAYLANG['TXT_NEWS_FONT_COLOR']}
var rssFeedFontSize = 8; // {$_ARRAYLANG['TXT_NEWS_FONT_SIZE']}
var rssFeedFont = "Arial, Verdana"; // {$_ARRAYLANG['TXT_NEWS_FONT']}
var rssFeedLimit = 10; // {$_ARRAYLANG['TXT_NEWS_DISPLAY_LIMIT']}
var rssFeedShowDate = true; // {$_ARRAYLANG['TXT_NEWS_SHOW_NEWS_DATE']}
var rssFeedTarget = "_blank"; // _blank | _parent | _self | _top
// --&gt;
&lt;/script&gt;
&lt;script type="text/javascript" language="JavaScript" src="$jsFeedUrl"&gt;&lt;/script&gt;
&lt;noscript&gt;
&lt;a href="$rssFeedUrl"&gt;$hostname - {$_ARRAYLANG['TXT_NEWS_SHOW_NEWS']}&lt;/a&gt;
&lt;/noscript&gt;
RSS2JSCODE;

		$this->_objTpl->setVariable(array(
			'NEWS_HOSTNAME'		=> $hostname,
			'NEWS_RSS2JS_CODE'	=> $rss2jsCode,
			'NEWS_RSS2JS_URL'	=> $jsFeedUrl,
			'NEWS_RSS_FEED_URL'	=> $rssFeedUrl
		));
		return $this->_objTpl->get();
	}
}
?>
