<?PHP
/**
* Modul Feed
*
* Manages the RSS feeds
*
* @copyright CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author Astalavista Development Team <thun@astalvista.ch>
* @module news
* @modulegroup modules
* @access public
* @version 1.0.0
*/


class rssFeed {
	var $xmlType;
	var $filePath;
	var $fileName = array();
	var $newsLimit;
	var $langId;

	var $channelTitle;
	var $channelLink;
	var $channelDescription;
	var $channelLanguage;
	var $channelCopyright;
	var $channelGenerator;
	var $channelWebmaster;
	var $itemLink;



	/**
    * Constructor
    *
	* @global	array		$_CONFIG
	* @global	string		$objDatabase
    */
	function rssFeed(){
		global $_CONFIG, $objInit, $objDatabase;

		$this->langId=$objInit->userFrontendLangId;

		$query = "SELECT lang FROM ".DBPREFIX."languages WHERE id='$this->langId'";
		$objResult = $objDatabase->Execute($query);

		$this->xmlType = "headlines";
		$this->filePath = ASCMS_FEED_PATH . '/';
		$this->channelLink = "http://".$_SERVER['SERVER_NAME'];
		$this->channelCopyright = "http://".$_SERVER['SERVER_NAME'];
		$this->channelGenerator = $_CONFIG['coreCmsName'];
		$this->channelLanguage  = $objResult->fields['lang'];
		$serverPort = $_SERVER['SERVER_PORT'] == 80 ? "" : ":".intval($_SERVER['SERVER_PORT']);
		$this->itemLink = "http://".$_SERVER['SERVER_NAME'].$serverPort.ASCMS_PATH_OFFSET."/index.php?section=news&amp;cmd=details&amp;newsid=";
		$this->fileName[1] = 'news_headlines_'.$objResult->fields['lang'].'.xml';
		$this->fileName[2] = 'news_'.$objResult->fields['lang'].'.xml';
		$this->newsLimit = 20;
	}


	/**
    * checkPermissions: checks if the permissions on the feed-directory are correct
    *
	* @return   boolean
    */
	function checkPermissions(){
		if(is_writeable($this->filePath) AND is_dir($this->filePath)){
			return true;
		} else {
			return false;
		}
	}


	/**
    * deletes the rss news feed file
    *
    */
	function delete(){
		@unlink($this->filePath.$this->fileName[2]);
		@unlink($this->filePath.$this->fileName[1]);
	}



	/**
    * creates the rss news feed file
    *
	* @global	string		$objDatabase
    */
    function create(){
    	global $_FRONTEND_LANGID, $objDatabase;

    	$xmlOutput = "";
    	// $objDatabase->debug=true;

    	if ($this->checkPermissions()){
		    $xmlOutput .= "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n";
			$xmlOutput .= "<rss version=\"2.0\">\n";
			$xmlOutput .= "<channel>\n";
			$xmlOutput .= "<title>".$this->channelTitle."</title>\n";
			$xmlOutput .= "<description>".$this->channelDescription."</description>\n";
			$xmlOutput .= "<link>".$this->channelLink."</link>\n";
			$xmlOutput .= "<copyright>".$this->channelCopyright."</copyright>\n";
			$xmlOutput .= "<webMaster>".$this->channelWebmaster."</webMaster>\n";
			$xmlOutput .= "<generator>".$this->channelGenerator."</generator>\n";
			$xmlOutput .= "<lastBuildDate>".date('r',time())."</lastBuildDate>\n";
			$xmlOutput .= "<language>".$this->channelLanguage."</language>\n";

			$query = "SELECT n.id AS newsid,
			                   n.date,
			                   n.title,
			                   n.text,
			                   n.source,
			                   u.firstname,
			                   u.lastname,
			                   n.lang,
			                   n.userid,
			                   u.id
						FROM ".DBPREFIX."module_news AS n,
			                 ".DBPREFIX."access_users AS u
						WHERE n.status=1 AND n.userid = u.id AND n.lang = ".$_FRONTEND_LANGID."
						ORDER BY n.date DESC";

			$objResult = $objDatabase->SelectLimit($query, $this->newsLimit);

			while (!$objResult->EOF) {
				$xmlOutput .= "<item>\n";
				$xmlOutput .= "<title>".htmlspecialchars($objResult->fields['title'])."</title>\n";
				if ($this->xmlType == 'fulltext'){
					$xmlOutput .= "<description>".htmlspecialchars($objResult->fields['text'])."</description>\n";
					//$xmlOutput .= "<description>".$objResult->fields['text')."</description>";
					$xmlOutput .= "<source>".htmlspecialchars($objResult->fields['source'])."</source>\n";
				}
				$xmlOutput .= "<pubDate>".date('r', $objResult->fields['date'])."</pubDate>\n";
				$xmlOutput .= "<link>".$this->itemLink.$objResult->fields['newsid']."</link>\n";
				$xmlOutput .= "</item>\n";
				$objResult->MoveNext();
			}
			$xmlOutput .= "</channel>\n";
			$xmlOutput .= "</rss>";

			if ($this->xmlType == 'fulltext'){
				$fileHandle = @fopen($this->filePath.$this->fileName[2],"w+");
			} else {
				$fileHandle = @fopen($this->filePath.$this->fileName[1],"w+");
			}
			if($fileHandle){
				@fwrite($fileHandle,$xmlOutput);
				@fclose($fileHandle);
			}
    	}
    }

    function createJsFeed()
    {
    	global $_FRONTEND_LANGID, $objDatabase;

    	$xmlJSOutput = "";

    	if ($this->checkPermissions()) {
			$xmlJSOutput = "var rssFeedNews = new Array()\n";

			$query = "SELECT id, date, title FROM ".DBPREFIX."module_news WHERE status=1 AND lang = ".$_FRONTEND_LANGID." ORDER BY date DESC";
			$objResult = $objDatabase->SelectLimit($query, $this->newsLimit);

			$nr = 0;
			while (!$objResult->EOF) {
				$xmlJSOutput .= "rssFeedNews[".$nr."] = new Array();\n";
				$xmlJSOutput .= "rssFeedNews[".$nr."]['title'] = '".addslashes(htmlspecialchars($objResult->fields['title']))."';\n";
				$xmlJSOutput .= "rssFeedNews[".$nr."]['link'] = '".$this->itemLink.$objResult->fields['id']."';\n";
				$xmlJSOutput .= "rssFeedNews[".$nr."]['date'] = '".date(ASCMS_DATE_SHORT_FORMAT, $objResult->fields['date'])."';\n";

				$objResult->MoveNext();
				$nr++;
			}

			$xmlJSOutput .= <<<XMLJSOUTPUT
if (typeof rssFeedFontColor != "string") {
	rssFeedFontColor = "";
} else {
	rssFeedFontColor = "color:"+rssFeedFontColor+";";
}
if (typeof rssFeedFontSize != "number") {
	rssFeedFontSize = "";
} else {
	rssFeedFontSize = "font-size:"+rssFeedFontSize+";";
}
if (typeof rssFeedTarget != "string") {
	rssFeedTarget = "target=\"_blank\"";;
} else {
	rssFeedTarget = "target=\""+rssFeedTarget+"\"";
}
if (typeof rssFeedFont != "string") {
	rssFeedFont = "";
} else {
	rssFeedFont = "font-family:"+rssFeedFont+";";
}
if (typeof rssFeedShowDate != "boolean") {
	rssFeedShowDate = false;
}

if (typeof rssFeedFontColor == "string" || typeof rssFeedFontSize != "number" || typeof rssFeedFont != "string") {
	style = 'style="'+rssFeedFontColor+rssFeedFontSize+rssFeedFont+'"';
}

if (typeof rssFeedLimit != 'number') {
	rssFeedLimit = 10;
}
if (rssFeedNews.length < rssFeedLimit) {
	rssFeedLimit = rssFeedNews.length;
}

var rssFeedNewsDate = "";
for (nr = 0; nr < rssFeedLimit; nr++) {
	if (rssFeedShowDate) {
		rssFeedNewsDate = rssFeedNews[nr]['date'];
	}
	document.write('<a href="'+rssFeedNews[nr]['link']+'" '+rssFeedTarget+' '+style+'>'+rssFeedNewsDate+' '+rssFeedNews[nr]['title']+'</a><br />');
}
XMLJSOUTPUT;

			$fileHandle = @fopen($this->filePath.'news_de.js',"w+");
			if ($fileHandle) {
				@fwrite($fileHandle,$xmlJSOutput);
				@fclose($fileHandle);
			}
    	}
    }
}
?>